#!/bin/sh
#
# Startup script for ProFTPd
#
# chkconfig: 345 85 15
# description: ProFTPD is an enhanced FTP server with \
#               a focus toward simplicity, security, and ease of configuration. \
#              It features a very Apache-like configuration syntax, \
#               and a highly customizable server infrastructure, \
#               including support for multiple 'virtual' FTP servers, \
#               anonymous FTP, and permission-based directory visibility.
# processname: proftpd
# pidfile: /var/run/proftpd.pid
# config: /etc/proftpd/proftpd.conf
#
# By: JoungKyun Kim <http://proftpd.oops.org>
# $Id: proftpd.init.d,v 1.3 2001/11/10 10:17:41 flood Exp $

# Source function library.
. /etc/rc.d/init.d/functions

RETVAL=0

FTPSHUT=/usr/sbin/ftpshut
SHUTMSG=/etc/shutmsg
LOCKFILE=/var/lock/subsys/proftpd-standalone
CONF=/etc/proftpd/proftpd.conf

# ServerType Check
CHK=$(cat ${CONF} | grep -i "^[[:space:]]*ServerType" | sed 's/.*\(standalone\|inetd\).*/\1/gI')

[ "${CHK}" = "inetd" ] && {
  CHKLANG=$(echo $LANG | sed 's/^\(ko\).*/\1/g')

  if [ "${CHKLANG}" = "ko" ] ;then
    echo 
    echo "proftpd.conf  ServerType  inetd mode   Ǿ ֽϴ."
    echo "ServerType   inetd mode    ũƮ proftpd binary "
    echo " ʽϴ. ServerType  inetd mode   inetd.conf "
    echo "proftpd  Ͻð inetd    ֽô  proftpd "
    echo "  ֽϴ."
  else
    echo 
    echo "ServerType Directive is appointed inetd mode in your proftpd.conf."
    echo "So, you start proftpd to use inetd. ServerType standalone doesn't use"
    echo "proftpd init script"
  fi

  exit 1
}

# See how we were called.
case "$1" in
	start)
		echo -n "Starting ProFTPd : "
		[ -f ${SHUTMSG} ] && rm -f ${SHUTMSG}
		daemon proftpd
		RETVAL=$?
		echo
		[ $RETVAL -eq 0 ] && touch ${LOCKFILE}
		;;
	stop)
		echo -n "Shutting down ProFTPd : "
		[ -f ${SHUTMSG} ] && rm -f ${SHUTMSG}
		killproc proftpd
		RETVAL=$?
		echo
		[ $RETVAL -eq 0 ] && rm -f ${LOCKFILE}
		;;
	status)
		status proftpd
		RETVAL=$?
		;;
	restart)
		$0 stop
		$0 start
		RETVAL=$?
		;;
	reload)
		echo -n "Reload ProFTPd : "
		killproc proftpd -HUP
		RETVAL=$?
		echo
		;;
	suspend)
		if [ -f $FTPSHUT ]; then
			if [ $# -gt 1 ]; then
				shift
				echo "ProFTPd : suspending with '$*'"
				$FTPSHUT $*
				RETVAL=$?
			else
				echo "ProFTPd : suspending NOW"
				$FTPSHUT now "Maintanance in progress"
				RETVAL=$?
			fi
		else
			echo "ProFTPd : no way to suspend"
		fi
  		;;
	resume)
		if [ -f ${SHUTMSG} ]; then
			echo "ProFTPd : allowing sessions again"
			rm -f ${SHUTMSG}
		else
			echo "ProFTPd : was not suspended"
		fi
  		;;
	*)
		echo -n "Usage: $0 {start|stop|restart|status|reload|resume"
  		if [ "$FTPSHUT" = "" ]; then
			echo "}"
		else
			echo "|suspend}"
			echo "suspend accepts additional arguments which are passed to ftpshut(8)"
		fi
		exit 1
esac

if [ $# -gt 1 ]; then
	shift
	$0 $*
fi

exit $RETVAL
